@@ -3,6 +3,9 @@ set -ex
 
 build="go run -mod=vendor build.go --enable-cgo"
 
+# Resets vendoring
+go mod vendor
+
 # Build binary
 if [[ "${CONDA_BUILD_CROSS_COMPILATION}" != "1" ]]; then
     ${build}
@@ -22,5 +25,6 @@ mkdir -p $PREFIX/bin
 mv restic $PREFIX/bin/restic
 
 # Setup and copy licenses of dependencies
-GOBIN=$PREFIX/bin go install github.com/google/go-licenses@latest
+GOBIN=${PREFIX}/bin go install github.com/google/go-licenses@latest
 go-licenses save github.com/restic/restic/cmd/restic --save_path=licenses
+rm -f ${PREFIX}/bin/go-licenses
